<?php
$protocol = $_SERVER["SERVER_PROTOCOL"];
if ( 'HTTP/1.1' != $protocol && 'HTTP/1.0' != $protocol ) $protocol = 'HTTP/1.0';
header( "$protocol 503 Service Temporarily Unavailable", true, 503 );
header( 'Content-Type: text/html; charset=utf-8' );
header( 'Retry-After: 3600'); // 1 hour

//* Logging
$current_url = "$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
$user_agent = "$_SERVER[HTTP_USER_AGENT]";
$remote_addr = "$_SERVER[REMOTE_ADDR]";

//* Proxy detection
$x_forward_for = "$_SERVER[HTTP_X_FORWARDED_FOR]";
if (empty($x_forward_for)) $x_forward_for = "empty";

//* Log contents
$log  = "URL: ".$current_url.PHP_EOL. 
		"DATE: ".date("F j, Y, g:i a").PHP_EOL.
        "User Agent: ".$user_agent.PHP_EOL.
        "HTTP_X_FORWARDED_FOR header: ".$x_forward_for.PHP_EOL.
        "Remote Address: ".$remote_addr.PHP_EOL.
        "-------------------------".PHP_EOL;

//* log file in /wp-content/dberror/
if ( !file_exists( './dberror/' ) ) { 
	mkdir( './dberror/', 0755, false); // Needs to be 0755 so you won't get mail spam when a DB error occurs. 
}
file_put_contents( './dberror/DBerror_log_'.date("j.n.Y").'.log', $log, FILE_APPEND);

//* Mail message
$message = "There is a problem with the database and log file has been created in /wp-content/dberror/. \r\n\r\nFound here: {$current_url} \r\nRemote address = {$remote_addr} \r\nHTTP_X address = {$x_forward_for} \r\nUser Agent: {$user_agent}";

//* Mail headers
$headers = "X-Priority: 1 (Highest)\n"; 
$headers .= "X-MSMail-Priority: High\n"; 
$headers .= "Importance: High\n";
$headers .= "From: Your Website";

//* Your email address
$email = "webmaster@example.com";

//* Mails you once daily.
if ( !file_exists( './dberror/DBerror_log_'.date("j.n.Y").'.log' ) ) {
	mail($email, "Database Error", $message, $headers);
}

?>
<!DOCTYPE html>
<html lang="en-US" dir="ltr">
<head>
	<title>Database error</title>
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
	<meta name='robots' content='noindex,follow' />
	<link rel='stylesheet' id='google-fonts-css'  href='//fonts.googleapis.com/css?family=Open+Sans:400' type='text/css' media='all' />
	<style>	
	html {
		background: #f1f1f1;
	}
	
	body, html {
		height: auto;
		margin: 0;
		padding: 0;
	}
	
	html, * {		
		-moz-box-sizing: border-box;
		-webkit-box-sizing: border-box;
		box-sizing: border-box;
	}
	
	body {
		color: #333;
		font-family: "Open Sans","Helvetica Neue","Helvetica", sans-serif;
		font-size: 15px;
		font-weight: 400;
		line-height: 1.6;
		text-rendering: optimizeLegibility;
		position: relative;
		height: 100%;
		min-height: 100vh;
		min-width: 0;
		background: rgba(0, 0, 0, 0.4);
		margin: 0 auto;
		display: block;
		border: 0;
	}
	
	body:before {
		content: " ";
		display: table;
		box-sizing: border-box;
	}
	
	body:after {
		content: "";
		display: block;
		clear: both;
		box-sizing: border-box;
	}
	
	#content {
		border-radius: 3px;
		padding: 0 20px 20px 20px;
		background: #ccc;
		z-index: 1;
		min-width: 320px;
		margin: 8% auto 40px;
		max-width: 360px;
	}

	h1 {
		padding: 15px;
		overflow: hidden;
		text-align: center;
	}
	
	h1 a {
		background-image: url('/wp-includes/images/wlw/wp-watermark.png');
		background-size: 84px 84px;
		background-position: center center;
		height: 84px;
		width: 84px;
		margin: 0 auto;
		background-repeat: no-repeat;
		color: #999;
		font-size: 20px;
		font-weight: 400;
		line-height: 1.3em;
		padding: 0;
		text-decoration: none;
		text-indent: -9999px;
		outline: 0;
		overflow: hidden;
		display: block;
	}
	
	h2 {
		color: #18699b;
		margin: 0px auto 14px;
		font-weight: 400;
	}
	
	a {
		text-decoration: none;
	}
		
	p {
		margin: 0 auto 10px;
	}
	
	p.contact {
		margin: 14px auto 0px;
	}
	
	p.contact a {
		border: 1px solid rgba(0,0,0,0.05);
		border-bottom-color: rgba(119,205,252,0.25);
		border-radius: 2px;
		cursor: pointer;
		display: inline-block;
		font-size: 21px;
		font-size: 1.3rem;
		font-weight: 400;
		font-family: "Open Sans", sans-serif;
		height: auto;
		line-height: 1em;
		margin: 10px 0 0;
		padding: .6em .2em 0.7em;
		text-align: center;
		text-decoration: none;
		width: 100%;
		background-color: #047dbf;
		color: #fff;
		webkit-transition: all 0.1s ease-in-out;
		-moz-transition: all 0.1s ease-in-out;
		-ms-transition: all 0.1s ease-in-out;
		-o-transition: all 0.1s ease-in-out;
		transition: all 0.1s ease-in-out;
	}
	
	div.infoblock {
		margin: 0 auto;
		border: 1px solid rgba(0,0,0,.2);
		background: rgba(255, 255, 255, 1);
		border-radius: 3px;
		padding: 26px 24px 46px;
	}
	
	p.contact a:hover,
	p.contact a:active {
		background-color: #2191ce;
		color: #fff;
	}
	
	.footerblock {
		margin: 24px 0 0;
		padding: 0 24px 0;
		text-align: center;
	}
	
	.footerblock em, 
	.footerblock a {
		color: #999;
		font-size: 13px;
		line-height: 1.6;
	}
	</style>
</head>
<body>
	<div id="content">
		<h1><a href="http://example.com/" title="Your Website" tabindex="-1">Your Website</a></h1>
		<div class="infoblock">
			<h2>Database error</h2>
			<p>Unfortunately there has been an error connecting to our databases.</p>
			<p>We have been informed about this. If this error keeps occuring after an hour please contact us.</p>
			<p class="contact"><a href="http://example.com/contact/">Contact us</a></p>
		</div>	
		<div class="footerblock">
			<p><em>Some extra info.</em></p>
			<p><em><a href="http://example.com/">Inspire yourself.</a></em></p>
		</div>
	</div>
</body>
</html>
<?php die(); ?>